JsfWeb class

Web registrar used by Flutter's generated plugin registrant.

JSF's web runtime is implemented with conditional exports from package:jsf/jsf.dart, so registration does not need to install method channels or global state.

Constructors

JsfWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers the web plugin with Flutter.